# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.3](https://github.com/mrosata/mud-slop/compare/mud-slop-v0.1.2...mud-slop-v0.1.3) (2026-02-06)


### Bug Fixes

* profile not loading when installed from PyPI ([e723adb](https://github.com/mrosata/mud-slop/commit/e723adb0f6e0595c51cce98fba42c18eb62327f7))

## [0.1.2](https://github.com/mrosata/mud-slop/compare/mud-slop-v0.1.1...mud-slop-v0.1.2) (2026-02-06)


### Bug Fixes

* chain publish jobs directly to release-please workflow ([f8ad1e9](https://github.com/mrosata/mud-slop/commit/f8ad1e95622ada72b59ddee5ea9ad0e142510e47))
* chain publish jobs directly to release-please workflow ([d4221e9](https://github.com/mrosata/mud-slop/commit/d4221e943199484cfc33ac2018f843b11dce8469))

## [0.1.1](https://github.com/mrosata/mud-slop/compare/mud-slop-v0.1.0...mud-slop-v0.1.1) (2026-02-06)


### Features

* add automated release process with release-please and PyPI publishing ([5f39f97](https://github.com/mrosata/mud-slop/commit/5f39f97f18f482d3ad689a683fccaa310decfd56))

## [0.1.0] - Unreleased

### Added
- Initial release
- Curses-based terminal UI with ANSI color support
- GMCP protocol support with stats pane
- Conversation overlay for speech detection
- Info ticker for INFO: channel messages
- Map pane with room descriptions
- Help pager for in-game help content
- Debug logging to files
- Command history with prefix filtering
- Full line editing (cursor movement, word operations)
- Password masking during login
- Auto-login profiles via YAML configuration
- Scrollback with Page Up/Down navigation
